summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/ui/addressbooklinkwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/ui/addressbooklinkwidget.h')
-rw-r--r--kopete/libkopete/ui/addressbooklinkwidget.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/libkopete/ui/addressbooklinkwidget.h b/kopete/libkopete/ui/addressbooklinkwidget.h
index 0ff4a651..a20f021f 100644
--- a/kopete/libkopete/ui/addressbooklinkwidget.h
+++ b/kopete/libkopete/ui/addressbooklinkwidget.h
@@ -50,7 +50,7 @@ public:
/**
* Set the currently selected addressee
*/
- void setAddressee( const KABC::Addressee& addr );
+ void setAddressee( const TDEABC::Addressee& addr );
/**
* Set the current metacontact so that the selector dialog may be preselected
*/
@@ -61,9 +61,9 @@ public:
TQString uid() const;
signals:
/**
* Emitted when the selected addressee changed. addr is the KABC::Addressee that was selected. If addr.isEmpty() is empty, the clear button was clicked.
*/
- void addresseeChanged( const KABC::Addressee& addr );
+ void addresseeChanged( const TDEABC::Addressee& addr );
/**
* Provided so you can perform your own actions instead of opening the AddressBookSelectorWidget.
@@ -61,9 +61,9 @@ public:
signals:
/**
- * Emitted when the selected addressee changed. addr is the KABC::Addressee that was selected. If addr.isEmpty() is empty, the clear button was clicked.
+ * Emitted when the selected addressee changed. addr is the TDEABC::Addressee that was selected. If addr.isEmpty() is empty, the clear button was clicked.
*/